@@ -6,9 +6,9 @@ if( is_site_admin() == false ) {
 
 do_action('wpmuadminedit', '');
 
-if( $_GET[ 'id' ] ) { 
+if( isset($_GET[ 'id' ]) ) { 
 	$id = intval( $_GET[ 'id' ] ); 
-} elseif( $_POST[ 'id' ] ) { 
+} elseif( isset($_POST[ 'id' ]) ) { 
 	$id = intval( $_POST[ 'id' ] ); 
 }
 
@@ -24,18 +24,18 @@ switch( $_GET['action'] ) {
 			wp_die( __("You probably need to go back to the <a href='wpmu-options.php'>options page</a>") );
 
 		update_site_option( "WPLANG", $_POST['WPLANG'] );
-		
+
 		if( is_email( $_POST['admin_email'] ) )
 			update_site_option( "admin_email", $_POST['admin_email'] );
 
-		$illegal_names = split( ' ', $_POST['illegal_names'] );		
+		$illegal_names = split( ' ', $_POST['illegal_names'] );
 		foreach( (array) $illegal_names as $name ) {
 			$name = trim( $name );
 			if( $name != '' )
 				$names[] = trim( $name );
 		}
 		update_site_option( "illegal_names", $names );
-		
+
 		update_site_option( "registration", $_POST['registration'] );
 		update_site_option( "registrationnotification", $_POST['registrationnotification'] );
 
@@ -49,7 +49,7 @@ switch( $_GET['action'] ) {
 		} else {
 			update_site_option( "limited_email_domains", '' );
 		}
-		
+
 		if( $_POST['banned_email_domains'] != '' ) {
 			$banned_email_domains = split( "\n", stripslashes( $_POST[ 'banned_email_domains' ] ) );
 			foreach( (array) $banned_email_domains as $domain ) {
@@ -59,7 +59,7 @@ switch( $_GET['action'] ) {
 		} else {
 			update_site_option( "banned_email_domains", '' );
 		}
-		
+
 		update_site_option( "menu_items", $_POST['menu_items'] );
 		update_site_option( "blog_upload_space", $_POST['blog_upload_space'] );
 		update_site_option( "upload_filetypes", $_POST['upload_filetypes'] );
@@ -67,7 +67,8 @@ switch( $_GET['action'] ) {
 		update_site_option( "first_post", $_POST['first_post'] );
 		update_site_option( "welcome_email", $_POST['welcome_email'] );
 		update_site_option( "fileupload_maxk", $_POST['fileupload_maxk'] );
-		
+		update_site_option( "admin_notice_feed", clean_url( $_POST['admin_notice_feed'] ) );
+
 		$site_admins = explode( ' ', str_replace( ",", " ", $_POST['site_admins'] ) );
 		if ( is_array( $site_admins ) ) {
 			$mainblog_id = $wpdb->get_var( "SELECT blog_id FROM {$wpdb->blogs} WHERE domain='{$current_site->domain}' AND path='{$current_site->path}'" );
@@ -88,21 +89,21 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( "updated", "true", $_SERVER['HTTP_REFERER'] ) );
 		exit();
 	break;
-	
+
 	// Blogs
 	case "addblog":
 		check_admin_referer('add-blog');
 
 		$blog = $_POST['blog'];
-		$domain = strtolower( wp_specialchars( $blog['domain'] ) );
-		$email = wp_specialchars( $blog['email'] );
-		$title = stripslashes( wp_specialchars( $blog['title'] ) );
-		
+		$domain = sanitize_user( str_replace( '/', '', $blog[ 'domain' ] ) );
+		$email = sanitize_email( $blog[ 'email' ] );
+		$title = $blog[ 'title' ];
+
 		if ( empty($domain) || empty($email))
 			wp_die( __('Missing blog address or email address.') );
 		if( !is_email( $email ) ) 
 			wp_die( __('Invalid email address') ); 
-		
+
 		if( constant('VHOST') == 'yes' ) {
 			$newdomain = $domain.".".$current_site->domain;
 			$path = $base;
@@ -123,20 +124,20 @@ switch( $_GET['action'] ) {
 		}
 
 		$wpdb->hide_errors();
-		$blog_id = wpmu_create_blog($newdomain, $path, $title, $user_id , array( "public" => 1 ), $current_site->id);
+		$id = wpmu_create_blog($newdomain, $path, $title, $user_id , array( "public" => 1 ), $current_site->id);
 		$wpdb->show_errors();
-		if( !is_wp_error($blog_id) ) {
+		if( !is_wp_error($id) ) {
 			if( get_user_option( $user_id, 'primary_blog' ) == 1 )
-				update_user_option( $user_id, 'primary_blog', $blog_id, true );
-			$content_mail = sprintf( __( "New blog created by %1s\n\nAddress: http://%2s\nName: %3s"), $current_user->user_login , $newdomain.$path, $title );
+				update_user_option( $user_id, 'primary_blog', $id, true );
+			$content_mail = sprintf( __( "New blog created by %1s\n\nAddress: http://%2s\nName: %3s"), $current_user->user_login , $newdomain.$path, stripslashes( $title ) );
 			wp_mail( get_site_option('admin_email'),  sprintf(__('[%s] New Blog Created'), $current_site->site_name), $content_mail, 'From: "Site Admin" <' . get_site_option( 'admin_email' ) . '>' );
 			wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'add-blog'), $_SERVER['HTTP_REFERER'] ) );
 			exit();
 		} else {
-			wp_die( $blog_id->get_error_message() );
+			wp_die( $id->get_error_message() );
 		}
 	break;
-	
+
 	case "updateblog":
 		check_admin_referer('editblog');
 		if( empty( $_POST ) )
@@ -148,7 +149,7 @@ switch( $_GET['action'] ) {
 		} else {
 			$_POST['option']['allowedthemes'] = '';
 		}
-		
+
 		if( is_array( $_POST['option'] ) ) {
 			$c = 1;
 			$count = count( $_POST['option'] );
@@ -164,10 +165,11 @@ switch( $_GET['action'] ) {
 
 		if( get_blog_option( $id, 'siteurl' ) != 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] )
 			update_blog_option( $id, 'siteurl', 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] );
-		
+
 		if( get_blog_option( $id, 'home' ) != 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] )
 			update_blog_option( $id, 'home', 'http://' . $_POST['blog']['domain'] . $_POST['blog']['path'] );
-		
+		$wp_rewrite->flush_rules();
+
 		// update blogs table
 		$result = $wpdb->query("UPDATE {$wpdb->blogs} SET
 				domain       = '".$_POST['blog']['domain']."',
@@ -179,9 +181,9 @@ switch( $_GET['action'] ) {
 				deleted      = '".$_POST['blog']['deleted']."',
 				spam         = '".$_POST['blog']['spam']."' 
 			WHERE  blog_id = '$id'");
-			
+
 		update_blog_status( $id, 'spam', $_POST['blog']['spam'] );
-		
+
 		// user roles
 		if( is_array( $_POST['role'] ) == true ) {
 			$newroles = $_POST['role'];
@@ -201,11 +203,8 @@ switch( $_GET['action'] ) {
 		// remove user
 		if( is_array( $_POST['blogusers'] ) ) {
 			reset( $_POST['blogusers'] );
-			foreach ( (array) $_POST['blogusers'] as $key => $val ) {
-				delete_usermeta( $key, $wpdb->base_prefix.$id.'_capabilities' );
-				delete_usermeta( $key, $wpdb->base_prefix.$id.'_user_level' );
-				delete_usermeta( $key, 'primary_blog', $id ); // Delete primary blog if need.
-			}
+			foreach ( (array) $_POST['blogusers'] as $key => $val )
+				remove_user_from_blog( $key, $id );
 		}
 
 		// change password
@@ -233,25 +232,23 @@ switch( $_GET['action'] ) {
 		// add user?
 		if( $_POST['newuser'] != '' ) {
 			$newuser = $_POST['newuser'];
-			$userid = $wpdb->get_var( "SELECT ID FROM " . $wpdb->users . " WHERE user_login = '$newuser'" );
-			if( $userid ) {
-				$user = $wpdb->get_var( "SELECT user_id FROM " . $wpdb->usermeta . " WHERE user_id='$userid' AND meta_key='wp_" . $id . "_capabilities'" );
-				if( $user == false )
-					$wpdb->query( "INSERT INTO " . $wpdb->usermeta . "( `umeta_id` , `user_id` , `meta_key` , `meta_value` ) VALUES ( NULL, '$userid', '" . $wpdb->base_prefix . $id . "_capabilities', 'a:1:{s:" . strlen( $_POST['new_role'] ) . ":\"" . $_POST['new_role'] . "\";b:1;}')" );
-			}
+			$userid = $wpdb->get_var( $wpdb->prepare( "SELECT ID FROM " . $wpdb->users . " WHERE user_login = %s", $newuser ) );
+			if( $userid )
+				add_user_to_blog( $id, $userid, $_POST['new_role'] );
 		}
+		do_action( 'wpmu_update_blog_options' );
 		wpmu_admin_do_redirect( "wpmu-blogs.php?action=editblog&updated=true&id=".$id );
 	break;
-	
+
 	case "deleteblog":
 		check_admin_referer('deleteblog');
 		if( $id != '0' && $id != '1' )
 			wpmu_delete_blog( $id, true );
-			
+
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'delete'), $_POST[ 'ref' ] ) );
 		exit();
 	break;
-	
+
 	case "allblogs":
 		check_admin_referer('allblogs');
 		foreach ( (array) $_POST['allblogs'] as $key => $val ) {
@@ -274,7 +271,7 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => $blogfunction), $_SERVER['HTTP_REFERER'] ) );
 		exit();
 	break;
-	
+
 	case "archiveblog":
 		check_admin_referer('archiveblog');
 		update_blog_status( $id, "archived", '1' );
@@ -282,7 +279,7 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'archive'), $_POST['ref'] ) );
 		exit();
 	break;
-	
+
 	case "unarchiveblog":
 		check_admin_referer('unarchiveblog');
 		do_action( "unarchive_blog", $id );
@@ -290,7 +287,7 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'unarchive'), $_POST['ref'] ) );
 		exit();
 	break;
-	
+
 	case "activateblog":
 		check_admin_referer('activateblog');
 		update_blog_status( $id, "deleted", '0' );
@@ -298,7 +295,7 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( "updated", array('updated' => 'true', 'action' => 'activate'), $_POST['ref'] ) );
 		exit();
 	break;
-	
+
 	case "deactivateblog":
 		check_admin_referer('deactivateblog');
 		do_action( "deactivate_blog", $id );
@@ -306,7 +303,7 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'deactivate'), $_POST['ref'] ) );
 		exit();
 	break;
-	
+
 	case "unspamblog":
 		check_admin_referer('unspamblog');
 		update_blog_status( $id, "spam", '0' );
@@ -314,7 +311,7 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'unspam'), $_POST['ref'] ) );
 		exit();
 	break;
-	
+
 	case "spamblog":
 		check_admin_referer('spamblog');
 		update_blog_status( $id, "spam", '1' );
@@ -322,22 +319,22 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'spam'), $_POST['ref'] ) );
 		exit();
 	break;
-	
+
 	case "mature":
 		update_blog_status( $id, 'mature', '1' );
 		do_action( 'mature_blog', $id );
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'mature'), $_POST['ref'] ) );
 		exit();
 	break;
-	
+
 	case "unmature":
 		update_blog_status( $id, 'mature', '0' );
 		do_action( 'unmature_blog', $id );
-		
+
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'umature'), $_POST['ref'] ) );
 		exit();
 	break;
-	
+
 	// Themes
     case "updatethemes":
     	if( is_array( $_POST['theme'] ) ) {
@@ -352,10 +349,11 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'themes'), $_SERVER['HTTP_REFERER'] ) );
 		exit();
 	break;
-	
+
 	// Common
 	case "confirm":
-		global $wp_locale;
+		$referrer = ( isset($_GET['ref']) ) ? stripslashes($_GET['ref']) : $_SERVER['HTTP_REFERER'];
+		$referrer = clean_url($referrer);
 		if( !headers_sent() ){
 			nocache_headers();
 			header( 'Content-Type: text/html; charset=utf-8' );
@@ -367,27 +365,23 @@ switch( $_GET['action'] ) {
 				<title><?php _e("WordPress MU &rsaquo; Confirm your action"); ?></title>
 
 				<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
-				<link rel="stylesheet" href="css/install.css" type="text/css" />
-				<?php if ( ( $wp_locale ) && ('rtl' == $wp_locale->text_direction) ) : ?>
-					<link rel="stylesheet" href="css/install-rtl.css" type="text/css" />
-				<?php endif; ?>
+				<?php wp_admin_css( 'install', true ); ?>
 			</head>
 			<body id="error-page">
 				<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
 				<form action='wpmu-edit.php?action=<?php echo wp_specialchars( $_GET[ 'action2' ] ) ?>' method='post'>
 					<input type='hidden' name='action' value='<?php echo wp_specialchars( $_GET['action2'] ) ?>' />
 					<input type='hidden' name='id' value='<?php echo wp_specialchars( $id ); ?>' />
-					<input type='hidden' name='ref' value='<?php if( isset( $_GET['ref'] ) ) {echo wp_specialchars( $_GET['ref'] ); } else { echo $_SERVER['HTTP_REFERER']; } ?>' />
+					<input type='hidden' name='ref' value='<?php echo $referrer; ?>' />
 					<?php wp_nonce_field( $_GET['action2'] ) ?>
-					<p>						
-						<?php echo wp_specialchars( $_GET['msg'] ) ?><br />
-						<input class="button" type='submit' value='<?php _e("Confirm"); ?>' /></p>					
+					<p><?php echo wp_specialchars( stripslashes($_GET['msg']) ); ?></p>
+					<p class="submit"><input class="button" type='submit' value='<?php _e("Confirm"); ?>' /></p>						
 				</form>
 			</body>
 		</html>
 		<?php
 	break;
-	
+
 	// Users
 	case "deleteuser":
 		check_admin_referer('deleteuser');
@@ -397,16 +391,32 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'delete'), $_POST['ref'] ) );
 		exit();
 	break;
-	
+
 	case "allusers":
 		check_admin_referer('allusers');
+		if ( isset($_POST['alluser_delete']) ) {
+			require_once('admin-header.php');
+			echo '<div class="wrap" style="position:relative;">';
+			confirm_delete_users( $_POST['allusers'] );
+			echo '</div>';
+		} elseif( isset( $_POST[ 'alluser_transfer_delete' ] ) ) {
+			if( is_array( $_POST[ 'blog' ] ) && !empty( $_POST[ 'blog' ] ) ) {
+				foreach( $_POST[ 'blog' ] as $id => $users ) {
+					foreach( $users as $blogid => $user_id ) {
+						$wpdb->query( "UPDATE {$wpdb->base_prefix}{$blogid}_posts SET post_author = '{$user_id}' WHERE post_author = '{$id}'" );
+					}
+				}
+			}
+			if( is_array( $_POST[ 'user' ] ) && !empty( $_POST[ 'user' ] ) )
+				foreach( $_POST[ 'user' ] as $id )
+					wpmu_delete_user( $id );
+
+			wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'all_delete'), 'wpmu-users.php' ) );
+		} else {
 		foreach ( (array) $_POST['allusers'] as $key => $val ) {
 			if( $val != '' && $val != '0' && $val != '1' ) {
 				$user_details = get_userdata( $val );
-				if ( isset($_POST['alluser_delete']) ) {
-					wpmu_delete_user($val);
-					$userfunction = 'all_delete';
-				} elseif ( isset($_POST['alluser_spam']) ) {
+				if ( isset($_POST['alluser_spam']) ) {
 					$userfunction = 'all_spam';
 					$blogs = get_blogs_of_user( $val, true );
 					foreach ( (array) $blogs as $key => $details ) {
@@ -424,11 +434,12 @@ switch( $_GET['action'] ) {
 					update_user_status( $val, "spam", '0', 1 );
 				}
 			}
-		}		
+		}
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => $userfunction), $_SERVER['HTTP_REFERER'] ) );
+		}
 		exit();
 	break;
-		
+
 	case "adduser":
 		check_admin_referer('add-user');
 
@@ -454,10 +465,10 @@ switch( $_GET['action'] ) {
 		wp_redirect( add_query_arg( array('updated' => 'true', 'action' => 'add'), $_SERVER['HTTP_REFERER'] ) );
 		exit();
 	break;
-	
+
 	default:
 		wpmu_admin_do_redirect( "wpmu-admin.php" );
-	break;	
+	break;
 }
 
 ?>
