@@ -68,6 +68,10 @@ if ( empty( $_SERVER['REQUEST_URI'] ) ) {
 	}
 	else
 	{
+		// Use ORIG_PATH_INFO if there is no PATH_INFO
+		if ( !isset($_SERVER['PATH_INFO']) && isset($_SERVER['ORIG_PATH_INFO']) )
+			$_SERVER['PATH_INFO'] = $_SERVER['ORIG_PATH_INFO'];
+
 		// Some IIS + PHP configurations puts the script-name in the path-info (No need to append it twice)
 		if ( isset($_SERVER['PATH_INFO']) ) {
 			if ( $_SERVER['PATH_INFO'] == $_SERVER['SCRIPT_NAME'] )
@@ -93,15 +97,18 @@ if (strpos($_SERVER['SCRIPT_NAME'], 'php.cgi') !== false)
 
 // Fix empty PHP_SELF
 $PHP_SELF = $_SERVER['PHP_SELF'];
-if ( empty($PHP_SELF) )
+if ( empty($PHP_SELF) || constant( 'VHOST' ) == 'no' )
 	$_SERVER['PHP_SELF'] = $PHP_SELF = preg_replace("/(\?.*)?$/",'',$_SERVER["REQUEST_URI"]);
 
 if ( version_compare( '4.3', phpversion(), '>' ) ) {
-	die( 'Your server is running PHP version ' . phpversion() . ' but WordPress requires at least 4.3.' );
+	die( sprintf( /*WP_I18N_OLD_PHP*/'Your server is running PHP version %s but WordPress requires at least 4.3.'/*/WP_I18N_OLD_PHP*/, php_version() ) );
 }
 
-if ( !extension_loaded('mysql') && !file_exists(ABSPATH . 'wp-content/db.php') )
-	die( 'Your PHP installation appears to be missing the MySQL extension which is required by WordPress.' );
+if ( !defined('WP_CONTENT_DIR') )
+	define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' ); // no trailing slash, full paths only - WP_CONTENT_URL is defined further down
+
+if ( !extension_loaded('mysql') && !file_exists(WP_CONTENT_DIR . '/db.php') )
+	die( /*WP_I18N_OLD_MYSQL*/'Your PHP installation appears to be missing the MySQL extension which is required by WordPress.'/*/WP_I18N_OLD_MYSQL*/ );
 
 /**
  * timer_start() - PHP 4 standard microtime start capture
@@ -166,7 +173,7 @@ if (defined('WP_DEBUG') and WP_DEBUG == true) {
 
 // For an advanced caching plugin to use, static because you would only want one
 if ( defined('WP_CACHE') )
-	@include ABSPATH . 'wp-content/advanced-cache.php';
+	@include WP_CONTENT_DIR . '/advanced-cache.php';
 
 /**
  * Stores the location of the WordPress directory of functions, classes, and core content.
@@ -175,30 +182,28 @@ if ( defined('WP_CACHE') )
  */
 define('WPINC', 'wp-includes');
 
-if ( !defined('LANGDIR') ) {
+if ( !defined('WP_LANG_DIR') ) {
 	/**
-	 * Stores the location of the language directory. First looks for language folder in wp-content
+	 * Stores the location of the language directory. First looks for language folder in WP_CONTENT_DIR
 	 * and uses that folder if it exists. Or it uses the "languages" folder in WPINC.
 	 *
 	 * @since 2.1.0
 	 */
-	if ( file_exists(ABSPATH . 'wp-content/languages') && @is_dir(ABSPATH . 'wp-content/languages') )
-		define('LANGDIR', 'wp-content/languages'); // no leading slash, no trailing slash
-	else
-		define('LANGDIR', WPINC . '/languages'); // no leading slash, no trailing slash
+	if ( file_exists(WP_CONTENT_DIR . '/languages') && @is_dir(WP_CONTENT_DIR . '/languages') ) {
+		define('WP_LANG_DIR', WP_CONTENT_DIR . '/languages'); // no leading slash, no trailing slash, full path, not relative to ABSPATH
+		if (!defined('LANGDIR')) {
+			// Old static relative path maintained for limited backwards compatibility - won't work in some cases
+			define('LANGDIR', 'wp-content/languages');
+		}
+	} else {
+		define('WP_LANG_DIR', ABSPATH . WPINC . '/languages'); // no leading slash, no trailing slash, full path, not relative to ABSPATH
+		if (!defined('LANGDIR')) {
+			// Old relative path maintained for backwards compatibility
+			define('LANGDIR', WPINC . '/languages');
+		}
+	}
 }
 
-/**
- * Allows for the plugins directory to be moved from the default location.
- *
- * This isn't used everywhere. Constant is not used in plugin_basename()
- * which might cause conflicts with changing this.
- *
- * @since 2.1
- */
-if ( !defined('PLUGINDIR') )
-	define('PLUGINDIR', 'wp-content/plugins'); // no leading slash, no trailing slash
-
 require (ABSPATH . WPINC . '/compat.php');
 require (ABSPATH . WPINC . '/functions.php');
 require (ABSPATH . WPINC . '/classes.php');
@@ -208,51 +213,32 @@ require_wp_db();
 if ( !empty($wpdb->error) )
 	dead_db();
 
-$prefix = $wpdb->set_prefix($table_prefix);
+$prefix = $wpdb->set_prefix($table_prefix); // set up global tables
 
 if ( is_wp_error($prefix) )
-	wp_die('<strong>ERROR</strong>: <code>$table_prefix</code> in <code>wp-config.php</code> can only contain numbers, letters, and underscores.');
-// Table names. prefix is bare "wp_"
-$wpdb->blogs		= $wpdb->prefix . 'blogs';
-$wpdb->site		= $wpdb->prefix . 'site';
-$wpdb->sitemeta		= $wpdb->prefix . 'sitemeta';
-$wpdb->sitecategories	= $wpdb->prefix . 'sitecategories';
-$wpdb->signups		= $wpdb->prefix . 'signups';
-$wpdb->registration_log	= $wpdb->prefix . 'registration_log';
-$wpdb->blog_versions	= $wpdb->prefix . 'blog_versions';
+	wp_die(/*WP_I18N_BAD_PREFIX*/'<strong>ERROR</strong>: <code>$table_prefix</code> in <code>wp-config.php</code> can only contain numbers, letters, and underscores.'/*/WP_I18N_BAD_PREFIX*/);
+
+if ( file_exists(WP_CONTENT_DIR . '/object-cache.php') )
+	require_once (WP_CONTENT_DIR . '/object-cache.php');
+else
+	require_once (ABSPATH . WPINC . '/cache.php');
+
+wp_cache_init();
+if ( function_exists('wp_cache_add_global_groups') ) {
+	wp_cache_add_global_groups(array ('users', 'userlogins', 'usermeta', 'site-options', 'site-lookup', 'blog-lookup', 'blog-details', 'rss'));
+	wp_cache_add_non_persistent_groups(array( 'comment', 'counts', 'plugins' ));
+}
 
 if( defined( 'SUNRISE' ) )
 	include_once( ABSPATH . 'wp-content/sunrise.php' );
 
 require_once ( ABSPATH . 'wpmu-settings.php' );
-$prefix = $table_prefix;
-$wpdb->prefix           = $table_prefix; // prefix now includes a blog_id
-$wpdb->posts            = $wpdb->prefix . 'posts';
-$wpdb->categories       = $wpdb->prefix . 'categories';
-$wpdb->post2cat         = $wpdb->prefix . 'post2cat';
-$wpdb->comments         = $wpdb->prefix . 'comments';
-$wpdb->link2cat         = $wpdb->prefix . 'link2cat';
-$wpdb->links            = $wpdb->prefix . 'links';
-$wpdb->linkcategories   = $wpdb->prefix . 'linkcategories';
-$wpdb->options          = $wpdb->prefix . 'options';
-$wpdb->postmeta         = $wpdb->prefix . 'postmeta';
-$wpdb->terms            = $wpdb->prefix . 'terms';
-$wpdb->term_taxonomy    = $wpdb->prefix . 'term_taxonomy';
-$wpdb->term_relationships = $wpdb->prefix . 'term_relationships';
-$wpdb->siteid           = $current_blog->site_id;
 $wpdb->blogid           = $current_blog->blog_id;
+$wpdb->siteid           = $current_blog->site_id;
+$wpdb->set_prefix($table_prefix); // set up blog tables
+$table_prefix = $table_prefix . $blog_id . '_';
 
-if ( defined('CUSTOM_USER_TABLE') )
-	$wpdb->users = CUSTOM_USER_TABLE;
-if ( defined('CUSTOM_USER_META_TABLE') )
-	$wpdb->usermeta = CUSTOM_USER_META_TABLE;
-
-if ( file_exists(ABSPATH . 'wp-content/object-cache.php') )
-	require_once (ABSPATH . 'wp-content/object-cache.php');
-else
-	require_once (ABSPATH . WPINC . '/cache.php');
-
-wp_cache_init();
+wp_cache_init(); // need to init cache again after blog_id is set
 
 if( !defined( "UPLOADS" ) )
 	define( "UPLOADS", "wp-content/blogs.dir/{$wpdb->blogid}/files/" );
@@ -261,23 +247,14 @@ require (ABSPATH . WPINC . '/plugin.php');
 require (ABSPATH . WPINC . '/default-filters.php');
 
 if( defined( "SHORTINIT" ) && constant( "SHORTINIT" ) == true ) // stop most of WP being loaded, we just want the basics
-	return;
+	return false;
 
 include_once(ABSPATH . WPINC . '/streams.php');
 include_once(ABSPATH . WPINC . '/gettext.php');
 require_once (ABSPATH . WPINC . '/l10n.php');
 
-if ( !is_blog_installed() && (strpos($_SERVER['PHP_SELF'], 'install.php') === false && !defined('WP_INSTALLING')) ) {
-	if ( defined('WP_SITEURL') )
-		$link = WP_SITEURL . '/wp-admin/install.php';
-	elseif (strpos($_SERVER['PHP_SELF'], 'wp-admin') !== false)
-		$link = preg_replace('|/wp-admin/?.*?$|', '/', $_SERVER['PHP_SELF']) . 'wp-admin/install.php';
-	else
-		$link = preg_replace('|/[^/]+?$|', '/', $_SERVER['PHP_SELF']) . 'wp-admin/install.php';
-	require_once(ABSPATH . WPINC . '/kses.php');
-	require_once(ABSPATH . WPINC . '/pluggable.php');
-	wp_redirect($link);
-	die(); // have to die here ~ Mark
+if ( !is_blog_installed() && !defined('WP_INSTALLING') ) {
+	die( __( 'The blog you have requested is not installed properly. Please contact the system administrator.' ) ); // have to die here ~ Mark
 }
 
 require (ABSPATH . WPINC . '/formatting.php');
@@ -309,20 +286,36 @@ require (ABSPATH . WPINC . '/canonical.php');
 require (ABSPATH . WPINC . '/shortcodes.php');
 require (ABSPATH . WPINC . '/media.php');
 
+if ( !defined('WP_CONTENT_URL') )
+	define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content'); // full url - WP_CONTENT_DIR is defined further up
+
 require_once( ABSPATH . WPINC . '/wpmu-functions.php' );
+require (ABSPATH . WPINC . '/wpmu-default-filters.php'); // WPmu Filters 
 
-if( defined( "WP_INSTALLING" ) == false )
+/**
+ * Allows for the plugins directory to be moved from the default location.
+ *
+ * @since 2.6
+ */
+if ( !defined('WP_PLUGIN_DIR') )
+	define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' ); // full path, no trailing slash
+if ( !defined('WP_PLUGIN_URL') )
+	define( 'WP_PLUGIN_URL', WP_CONTENT_URL . '/plugins' ); // full url, no trailing slash
+if ( !defined('PLUGINDIR') )
+	define( 'PLUGINDIR', 'wp-content/plugins' ); // Relative to ABSPATH.  For back compat.
+
+if( !isset($current_site->site_name) )
 	$current_site->site_name = get_site_option('site_name');
-
-if( $current_site->site_name == false ) {
+if( $current_site->site_name == false )
 	$current_site->site_name = ucfirst( $current_site->domain );
-}
 
-if( defined('WP_INSTALLING') == false ) {
-	$locale = get_option('WPLANG');
-	if( $locale === false )
-		$locale = get_site_option('WPLANG');
-}
+// Used to guarantee unique hash cookies
+$cookiehash = '';
+/**
+ * Used to guarantee unique hash cookies
+ * @since 1.5
+ */
+define('COOKIEHASH', '' );
 
 $wpdb->hide_errors();
 if( defined( 'MUPLUGINDIR' ) == false ) 
@@ -339,46 +332,61 @@ if( is_dir( ABSPATH . MUPLUGINDIR ) ) {
 }
 $wpdb->show_errors();
 
-if ( '1' == $current_blog->deleted )
+if ( '1' == $current_blog->deleted ) {
+	header('HTTP/1.1 410 Gone');
 	graceful_fail(__('This user has elected to delete their account and the content is no longer available.'));
+}
 
 if ( '2' == $current_blog->deleted )
-		graceful_fail(sprintf(__('This blog has not been activated yet. If you are having problems activating your blog, please contact <a href="mailto:%1$s">%1$s</a>.'), get_site_option( 'admin_email', "support@{$current_site->domain}" )));
+	graceful_fail( sprintf( __( 'This blog has not been activated yet. If you are having problems activating your blog, please contact <a href="mailto:%1$s">%1$s</a>.' ), str_replace( '@', ' AT ', get_site_option( 'admin_email', "support@{$current_site->domain}" ) ) ) );
 
-if( $current_blog->archived == '1' )
-    graceful_fail(__('This blog has been archived or suspended.'));
-
-if( $current_blog->spam == '1' )
-    graceful_fail(__('This blog has been archived or suspended.'));
-
-define('COOKIEHASH', '');
+if( $current_blog->archived == '1' || $current_blog->spam == '1' ) {
+	header('HTTP/1.1 410 Gone');
+	graceful_fail(__('This blog has been archived or suspended.'));
+}
 
 /**
  * Should be exactly the same as the default value of SECRET_KEY in wp-config-sample.php
  * @since 2.5
  */
 $wp_default_secret_key = 'put your unique phrase here';
+if( defined( 'SECRET_KEY' ) )
+	$wp_default_secret_key = SECRET_KEY;
 
 /**
  * It is possible to define this in wp-config.php
  * @since 2.0.0
  */
 if ( !defined('USER_COOKIE') )
-	define('USER_COOKIE', 'wordpressuser');
+	define('USER_COOKIE', 'wordpressuser_' . COOKIEHASH);
 
 /**
  * It is possible to define this in wp-config.php
  * @since 2.0.0
  */
 if ( !defined('PASS_COOKIE') )
-	define('PASS_COOKIE', 'wordpresspass');
+	define('PASS_COOKIE', 'wordpresspass_' . COOKIEHASH);
 
 /**
  * It is possible to define this in wp-config.php
  * @since 2.5
  */
 if ( !defined('AUTH_COOKIE') )
-	define('AUTH_COOKIE', 'wordpress');
+	define('AUTH_COOKIE', 'wordpress_' . COOKIEHASH);
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('SECURE_AUTH_COOKIE') )
+	define('SECURE_AUTH_COOKIE', 'wordpress_sec_' . COOKIEHASH);
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('LOGGED_IN_COOKIE') )
+	define('LOGGED_IN_COOKIE', 'wordpress_logged_in_' . COOKIEHASH);
 
 /**
  * It is possible to define this in wp-config.php
@@ -401,13 +409,48 @@ if ( !defined('COOKIEPATH') )
 if ( !defined('SITECOOKIEPATH') )
 	define('SITECOOKIEPATH', $current_site->path );
 
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('ADMIN_COOKIE_PATH') ) {
+	if( constant( 'VHOST' ) == 'no' ) {
+		define( 'ADMIN_COOKIE_PATH', SITECOOKIEPATH );
+	} else {
+		define( 'ADMIN_COOKIE_PATH', SITECOOKIEPATH . 'wp-admin' );
+	}
+}
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('PLUGINS_COOKIE_PATH') )
+	define( 'PLUGINS_COOKIE_PATH', preg_replace('|https?://[^/]+|i', '', WP_PLUGIN_URL)  );
+
 /**
  * It is possible to define this in wp-config.php
  * @since 2.0.0
  */
 if ( !defined('COOKIE_DOMAIN') )
 	define('COOKIE_DOMAIN', '.' . $current_site->domain);
-	
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('FORCE_SSL_ADMIN') )
+	define('FORCE_SSL_ADMIN', false);
+force_ssl_admin(FORCE_SSL_ADMIN);
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('FORCE_SSL_LOGIN') )
+	define('FORCE_SSL_LOGIN', false);
+force_ssl_login(FORCE_SSL_LOGIN);
+
 /**
  * It is possible to define this in wp-config.php
  * @since 2.5.0
@@ -418,15 +461,13 @@ if ( !defined( 'AUTOSAVE_INTERVAL' ) )
 
 require (ABSPATH . WPINC . '/vars.php');
 
-if ( !defined('PLUGINDIR') )
-	define('PLUGINDIR', 'wp-content/plugins'); // no leading slash, no trailing slash
 
 if ( get_option('active_plugins') ) {
 	$current_plugins = get_option('active_plugins');
 	if ( is_array($current_plugins) ) {
 		foreach ($current_plugins as $plugin) {
-			if ('' != $plugin && file_exists(ABSPATH . PLUGINDIR . '/' . $plugin))
-				include_once(ABSPATH . PLUGINDIR . '/' . $plugin);
+			if ( '' != $plugin && 0 == validate_file($plugin) && file_exists(WP_PLUGIN_DIR . '/' . $plugin) )
+				include_once(WP_PLUGIN_DIR . '/' . $plugin);
 		}
 	}
 }
@@ -448,6 +489,11 @@ if ( defined('WP_CACHE') && function_exists('wp_cache_postload') )
 
 do_action('plugins_loaded');
 
+$default_constants = array( 'WP_POST_REVISIONS' => true );
+foreach ( $default_constants as $c => $v )
+	@define( $c, $v ); // will fail if the constant is already defined
+unset($default_constants, $c, $v);
+
 // If already slashed, strip.
 if ( get_magic_quotes_gpc() ) {
 	$_GET    = stripslashes_deep($_GET   );
@@ -492,6 +538,7 @@ $wp_rewrite   =& new WP_Rewrite();
  */
 $wp           =& new WP();
 
+do_action('setup_theme');
 
 /**
  * Web Path to the current active template directory
@@ -513,7 +560,7 @@ load_default_textdomain();
  * @since 1.5.0
  */
 $locale = get_locale();
-$locale_file = ABSPATH . LANGDIR . "/$locale.php";
+$locale_file = WP_LANG_DIR . "/$locale.php";
 if ( is_readable($locale_file) )
 	require_once($locale_file);
 
